@@ -96,7 +96,7 @@ def open_parquet_file(
     # Make sure we have an `AbstractFileSystem` object
     # to work with
     if fs is None:
-        fs = url_to_fs(path, storage_options=(storage_options or {}))[0]
+        fs = url_to_fs(path, **(storage_options or {}))[0]
 
     # For now, `columns == []` not supported. Just use
     # default `open` command with `path` input
@@ -131,10 +131,8 @@ def open_parquet_file(
         cache_type="parts",
         cache_options={
             **options,
-            **{
-                "data": data.get(fn, {}),
-                "strict": strict,
-            },
+            "data": data.get(fn, {}),
+            "strict": strict,
         },
         **kwargs,
     )
@@ -164,9 +162,8 @@ def _get_parquet_byte_ranges(
 
     # Pass to specialized function if metadata is defined
     if metadata is not None:
-
         # Use the provided parquet metadata object
-        # to avoid transfering/parsing footer metadata
+        # to avoid transferring/parsing footer metadata
         return _get_parquet_byte_ranges_from_metadata(
             metadata,
             fs,
@@ -214,14 +211,12 @@ def _get_parquet_byte_ranges(
 
         # Check our footer samples and re-sample if necessary.
         missing_footer_starts = footer_starts.copy()
-        missing_footer_ends = footer_starts.copy()
         large_footer = 0
         for i, path in enumerate(paths):
             footer_size = int.from_bytes(footer_samples[i][-8:-4], "little")
             real_footer_start = file_sizes[i] - (footer_size + 8)
             if real_footer_start < footer_starts[i]:
                 missing_footer_starts[i] = real_footer_start
-                missing_footer_ends[i] = footer_starts[i]
                 large_footer = max(large_footer, (footer_size + 8))
         if large_footer:
             warnings.warn(
@@ -232,14 +227,14 @@ def _get_parquet_byte_ranges(
                 fs.cat_ranges(
                     paths,
                     missing_footer_starts,
-                    missing_footer_ends,
+                    footer_starts,
                 )
             ):
                 footer_samples[i] = block + footer_samples[i]
+                footer_starts[i] = missing_footer_starts[i]
 
         # Calculate required byte ranges for each path
         for i, path in enumerate(paths):
-
             # Deal with small-file case.
             # Just include all remaining bytes of the file
             # in a single range.
@@ -300,7 +295,7 @@ def _get_parquet_byte_ranges_from_metadata(
     """Simplified version of `_get_parquet_byte_ranges` for
     the case that an engine-specific `metadata` object is
     provided, and the remote footer metadata does not need to
-    be transfered before calculating the required byte ranges.
+    be transferred before calculating the required byte ranges.
     """
 
     # Use "engine" to collect data byte ranges
@@ -339,9 +334,9 @@ def _transfer_ranges(fs, blocks, paths, starts, ends):
 
 def _add_header_magic(data):
     # Add b"PAR1" to file headers
-    for i, path in enumerate(list(data.keys())):
+    for path in list(data.keys()):
         add_magic = True
-        for k in data[path].keys():
+        for k in data[path]:
             if k[0] == 0 and k[1] >= 4:
                 add_magic = False
                 break
@@ -350,7 +345,6 @@ def _add_header_magic(data):
 
 
 def _set_engine(engine_str):
-
     # Define a list of parquet engines to try
     if engine_str == "auto":
         try_engines = ("fastparquet", "pyarrow")
@@ -386,7 +380,6 @@ def _set_engine(engine_str):
 
 
 class FastparquetEngine:
-
     # The purpose of the FastparquetEngine class is
     # to check if fastparquet can be imported (on initialization)
     # and to define a `_parquet_byte_ranges` method. In the
@@ -409,7 +402,6 @@ class FastparquetEngine:
         footer=None,
         footer_start=None,
     ):
-
         # Initialize offset ranges and define ParqetFile metadata
         pf = metadata
         data_paths, data_starts, data_ends = [], [], []
@@ -417,7 +409,7 @@ class FastparquetEngine:
             pf = self.fp.ParquetFile(io.BytesIO(footer))
 
         # Convert columns to a set and add any index columns
-        # speficied in the pandas metadata (just in case)
+        # specified in the pandas metadata (just in case)
         column_set = None if columns is None else set(columns)
         if column_set is not None and hasattr(pf, "pandas_metadata"):
             md_index = [
@@ -440,16 +432,15 @@ class FastparquetEngine:
 
         # Loop through column chunks to add required byte ranges
         for r, row_group in enumerate(row_groups):
-            # Skip this row-group if we are targetting
+            # Skip this row-group if we are targeting
             # specific row-groups
             if row_group_indices is None or r in row_group_indices:
-
                 # Find the target parquet-file path for `row_group`
                 fn = self._row_group_filename(row_group, pf)
 
                 for column in row_group.columns:
                     name = column.meta_data.path_in_schema[0]
-                    # Skip this column if we are targetting a
+                    # Skip this column if we are targeting a
                     # specific columns
                     if column_set is None or name in column_set:
                         file_offset0 = column.meta_data.dictionary_page_offset
@@ -474,7 +465,6 @@ class FastparquetEngine:
 
 
 class PyarrowEngine:
-
     # The purpose of the PyarrowEngine class is
     # to check if pyarrow can be imported (on initialization)
     # and to define a `_parquet_byte_ranges` method. In the
@@ -497,7 +487,6 @@ class PyarrowEngine:
         footer=None,
         footer_start=None,
     ):
-
         if metadata is not None:
             raise ValueError("metadata input not supported for PyarrowEngine")
 
@@ -505,7 +494,7 @@ class PyarrowEngine:
         md = self.pq.ParquetFile(io.BytesIO(footer)).metadata
 
         # Convert columns to a set and add any index columns
-        # speficied in the pandas metadata (just in case)
+        # specified in the pandas metadata (just in case)
         column_set = None if columns is None else set(columns)
         if column_set is not None:
             schema = md.schema.to_arrow_schema()
@@ -513,22 +502,26 @@ class PyarrowEngine:
                 schema.metadata is not None and b"pandas" in schema.metadata
             )
             if has_pandas_metadata:
-                column_set |= set(
-                    json.loads(schema.metadata[b"pandas"].decode("utf8")).get(
-                        "index_columns", []
-                    )
-                )
+                md_index = [
+                    ind
+                    for ind in json.loads(
+                        schema.metadata[b"pandas"].decode("utf8")
+                    ).get("index_columns", [])
+                    # Ignore RangeIndex information
+                    if not isinstance(ind, dict)
+                ]
+                column_set |= set(md_index)
 
         # Loop through column chunks to add required byte ranges
         for r in range(md.num_row_groups):
-            # Skip this row-group if we are targetting
+            # Skip this row-group if we are targeting
             # specific row-groups
             if row_groups is None or r in row_groups:
                 row_group = md.row_group(r)
                 for c in range(row_group.num_columns):
                     column = row_group.column(c)
                     name = column.path_in_schema
-                    # Skip this column if we are targetting a
+                    # Skip this column if we are targeting a
                     # specific columns
                     split_name = name.split(".")[0]
                     if (
